# eric7.QtHelpInterface.HelpTopicDialog

Module implementing a dialog to select a help topic to display.

### Global Attributes

None

### Classes

HelpTopicDialog | Class implementing a dialog to select a help topic to display.

### Functions

None

## HelpTopicDialog

Class implementing a dialog to select a help topic to display.

### Derived from

QDialog, Ui_HelpTopicDialog

### Class Attributes

None

### Class Methods

None

### Methods

HelpTopicDialog | Constructor
document | Public method to retrieve the selected help topic.

### Static Methods

None

#### HelpTopicDialog (Constructor)

HelpTopicDialog(parent, helpKeyword, documents)

Constructor

parent (QWidget)
  reference to the parent widget
helpKeyword (str)
  keyword for the link set
documents (list of QHelpLink)
  list of help document link data structures

#### HelpTopicDialog.document

document()

Public method to retrieve the selected help topic.

Return:
  help document link for the selected help topic

Return Type:
  QHelpLink

Up